@@ -1,11 +1,12 @@
+import builtins
 import fnmatch
-from typing import List, Sequence, Dict, Any, Optional
+from collections.abc import Sequence
+from typing import Any
 
 from .abstract import Manager, Model
 from .ec2 import Instance
 from .mixins import TagsMixin
 
-
 # ----------------------------------------
 # Managers
 # ----------------------------------------
@@ -13,7 +14,7 @@ from .mixins import TagsMixin
 
 class LoadBalancerManager(Manager):
 
-    service = 'elbv2'
+    service = "elbv2"
 
     def get(self, pk: str, **_) -> "LoadBalancer":
         instances = self.get_many([pk])
@@ -21,25 +22,25 @@ class LoadBalancerManager(Manager):
             raise LoadBalancer.MultipleObjectsReturned(f"Got more than one load balancer when searching for pk={pk}")
         return instances[0]
 
-    def get_many(self, pks: List[str], **kwargs) -> Sequence["LoadBalancer"]:
+    def get_many(self, pks: list[str], **kwargs) -> Sequence["LoadBalancer"]:
         arns = []
         names = []
         kwargs = {}
         for pk in pks:
-            if pk.startswith('arn:'):
+            if pk.startswith("arn:"):
                 arns.append(pk)
             else:
                 names.append(pk)
         if names:
-            kwargs['Names'] = names
+            kwargs["Names"] = names
         if arns:
-            kwargs['LoadBalancerArns'] = arns
-        paginator = self.client.get_paginator('describe_load_balancers')
+            kwargs["LoadBalancerArns"] = arns
+        paginator = self.client.get_paginator("describe_load_balancers")
         response_iterator = paginator.paginate(**kwargs)
         lbs = []
         try:
             for response in response_iterator:
-                lbs.extend(response['LoadBalancers'])
+                lbs.extend(response["LoadBalancers"])
         except self.client.exceptions.LoadBalancerNotFoundException as e:
             raise LoadBalancer.DoesNotExist(str(e))
         return [LoadBalancer(lb) for lb in lbs]
@@ -47,39 +48,39 @@ class LoadBalancerManager(Manager):
     def list(
         self,
         vpc_id: str = None,
-        lb_type: str = 'any',
-        scheme: str = 'any',
+        lb_type: str = "any",
+        scheme: str = "any",
         name: str = None
     ) -> Sequence["LoadBalancer"]:
-        paginator = self.client.get_paginator('describe_load_balancers')
+        paginator = self.client.get_paginator("describe_load_balancers")
         response_iterator = paginator.paginate()
         lb_data = []
         for response in response_iterator:
-            lb_data.extend(response['LoadBalancers'])
+            lb_data.extend(response["LoadBalancers"])
         lbs = []
         for lb in lb_data:
-            if name and not fnmatch.fnmatch(lb['LoadBalancerName'], name):
+            if name and not fnmatch.fnmatch(lb["LoadBalancerName"], name):
                 continue
-            if vpc_id and lb['VpcId'] != vpc_id:
+            if vpc_id and lb["VpcId"] != vpc_id:
                 continue
-            if scheme not in ['any', lb['Scheme']]:
+            if scheme not in ["any", lb["Scheme"]]:
                 continue
-            if lb_type not in ['any', lb['Type']]:
+            if lb_type not in ["any", lb["Type"]]:
                 continue
             lbs.append(LoadBalancer(lb))
         return lbs
 
-    def get_tags(self, arn: str) -> List[Dict[str, str]]:
+    def get_tags(self, arn: str) -> builtins.list[dict[str, str]]:
         try:
             response = self.client.describe_tags(ResourceArns=[arn])
         except self.client.exceptions.LoadBalancerNotFoundException as e:
             raise LoadBalancer.DoesNotExist(str(e))
-        return response['TagDescriptions']['Tags']
+        return response["TagDescriptions"]["Tags"]
 
 
 class LoadBalancerListenerManager(Manager):
 
-    service = 'elbv2'
+    service = "elbv2"
 
     def get(self, pk: str, **_) -> "LoadBalancerListener":
         try:
@@ -88,71 +89,71 @@ class LoadBalancerListenerManager(Manager):
             )
         except self.client.exceptions.ListenerNotFoundException as e:
             raise LoadBalancerListener.DoesNotExist(str(e))
-        return LoadBalancerListener(response['Listeners'][0])
+        return LoadBalancerListener(response["Listeners"][0])
 
     def list(self, load_balancer: str) -> Sequence["LoadBalancerListener"]:
-        paginator = self.client.get_paginator('describe_listeners')
+        paginator = self.client.get_paginator("describe_listeners")
         kwargs = {}
         if load_balancer:
-            if not load_balancer.startswith('arn:'):
+            if not load_balancer.startswith("arn:"):
                 # This is a load balancer name
                 lb = LoadBalancer.objects.get(load_balancer)
                 load_balancer = lb.arn
-            kwargs['LoadBalancerArn'] = load_balancer
+            kwargs["LoadBalancerArn"] = load_balancer
         response_iterator = paginator.paginate(**kwargs)
         listeners = []
         try:
             for response in response_iterator:
-                listeners.extend(response['Listeners'])
+                listeners.extend(response["Listeners"])
         except self.client.exceptions.LoadBalancerNotFoundException as e:
             raise LoadBalancer.DoesNotExist(str(e))
         return [LoadBalancerListener(listener) for listener in listeners]
 
-    def get_tags(self, arn: str) -> List[Dict[str, str]]:
+    def get_tags(self, arn: str) -> builtins.list[dict[str, str]]:
         try:
             response = self.client.describe_tags(ResourceArns=[arn])
         except self.client.exceptions.LoadBalancerNotFoundException as e:
             raise LoadBalancer.DoesNotExist(str(e))
-        return response['TagDescriptions']['Tags']
+        return response["TagDescriptions"]["Tags"]
 
 
 class LoadBalancerListenerRuleManager(Manager):
 
-    service = 'elbv2'
+    service = "elbv2"
 
     def __init__(self):
         super().__init__()
-        self.cache: Dict[str, Dict[str, Any]] = {'load_balancers': {}}
+        self.cache: dict[str, dict[str, Any]] = {"load_balancers": {}}
 
     def get(self, pk: str, **_) -> "LoadBalancerListenerRule":
         return self.get_many([pk])[0]
 
-    def get_many(self, pks: List[str], **_) -> Sequence["LoadBalancerListenerRule"]:
-        paginator = self.client.get_paginator('describe_rules')
+    def get_many(self, pks: list[str], **_) -> Sequence["LoadBalancerListenerRule"]:
+        paginator = self.client.get_paginator("describe_rules")
         response_iterator = paginator.paginate(RuleArns=pks)
         rules = []
         for response in response_iterator:
-            rules.extend(response['Rules'])
+            rules.extend(response["Rules"])
         return [LoadBalancerListenerRule(rule) for rule in rules]
 
     def __get_rules_for_load_balancer(self, load_balancer_pk: str) -> Sequence["LoadBalancerListenerRule"]:
-        if load_balancer_pk not in self.cache['load_balancers']:
+        if load_balancer_pk not in self.cache["load_balancers"]:
             lb = LoadBalancer.objects.get(load_balancer_pk)
             listener_arns = [listener.arn for listener in lb.listeners]
-            rule_objects: List["LoadBalancerListenerRule"] = []
+            rule_objects: list[LoadBalancerListenerRule] = []
             for arn in listener_arns:
                 rule_objects.extend(self.list(listener_arn=arn))
-            self.cache['load_balancers'][load_balancer_pk] = rule_objects
-        return self.cache['load_balancers'][load_balancer_pk]
+            self.cache["load_balancers"][load_balancer_pk] = rule_objects
+        return self.cache["load_balancers"][load_balancer_pk]
 
     def __get_rules_for_target_group(self, target_group_arn: str) -> Sequence["LoadBalancerListenerRule"]:
         tg = TargetGroup.objects.get(target_group_arn)
-        load_balancer_pk = tg.data['LoadBalancerArns'][0]
+        load_balancer_pk = tg.data["LoadBalancerArns"][0]
         rule_objects = self.__get_rules_for_load_balancer(load_balancer_pk)
         matched_rules = []
         for obj in rule_objects:
-            for action in obj.data['Actions']:
-                if action['Type'] == 'forward' and action['TargetGroupArn'] == target_group_arn:
+            for action in obj.data["Actions"]:
+                if action["Type"] == "forward" and action["TargetGroupArn"] == target_group_arn:
                     # I'm making an important assumption here that the relevant target group is the one attached
                     # to the first 'forward' action on the rule, and that we only have one TargetGroup -- we're
                     # not using a weighted ForwardConfig with a list of TargetGroupArns.
@@ -174,53 +175,53 @@ class LoadBalancerListenerRuleManager(Manager):
                 'Use only one of "listener_arn", "load_balancer_pk", or "target_group_arn".'
             )
         kwargs = {}
-        rules: Sequence["LoadBalancerListenerRule"] = []
+        rules: Sequence[LoadBalancerListenerRule] = []
         if target_group_arn:
             rules = self.__get_rules_for_target_group(target_group_arn)
         elif load_balancer_pk:
             rules = self.__get_rules_for_load_balancer(load_balancer_pk)
         elif listener_arn:
-            kwargs['ListenerArn'] = listener_arn
-            paginator = self.client.get_paginator('describe_rules')
+            kwargs["ListenerArn"] = listener_arn
+            paginator = self.client.get_paginator("describe_rules")
             response_iterator = paginator.paginate(**kwargs)
             rules_data = []
             for response in response_iterator:
-                rules_data.extend(response['Rules'])
+                rules_data.extend(response["Rules"])
             rules = [LoadBalancerListenerRule(d, listener_arn=listener_arn) for d in rules_data]
         return rules
 
-    def get_tags(self, arn: str) -> List[Dict[str, str]]:
+    def get_tags(self, arn: str) -> builtins.list[dict[str, str]]:
         try:
             response = self.client.describe_tags(ResourceArns=[arn])
         except self.client.exceptions.LoadBalancerNotFoundException as e:
             raise LoadBalancer.DoesNotExist(str(e))
-        return response['TagDescriptions']['Tags']
+        return response["TagDescriptions"]["Tags"]
 
 
 class TargetGroupManager(Manager):
 
-    service = 'elbv2'
+    service = "elbv2"
 
     def get(self, pk: str, **_) -> "TargetGroup":
         return self.get_many([pk])[0]
 
-    def get_many(self, pks: List[str], **kwargs) -> Sequence["TargetGroup"]:
+    def get_many(self, pks: list[str], **kwargs) -> Sequence["TargetGroup"]:
         kwargs = {}
         for pk in pks:
-            if pk.startswith('arn:'):
-                if 'TargetGroupArns' not in kwargs:
-                    kwargs['TargetGroupArns'] = []
-                kwargs['TargetGroupArns'].append(pk)
+            if pk.startswith("arn:"):
+                if "TargetGroupArns" not in kwargs:
+                    kwargs["TargetGroupArns"] = []
+                kwargs["TargetGroupArns"].append(pk)
             else:
-                if 'Names' not in kwargs:
-                    kwargs['Names'] = []
-                kwargs['Names'].append(pk)
-        paginator = self.client.get_paginator('describe_target_groups')
+                if "Names" not in kwargs:
+                    kwargs["Names"] = []
+                kwargs["Names"].append(pk)
+        paginator = self.client.get_paginator("describe_target_groups")
         response_iterator = paginator.paginate(**kwargs)
         tgs = []
         try:
             for response in response_iterator:
-                tgs.extend(response['TargetGroups'])
+                tgs.extend(response["TargetGroups"])
         except self.client.exceptions.LoadBalancerNotFoundException as e:
             raise LoadBalancer.DoesNotExist(str(e))
         except self.client.exceptions.TargetGroupNotFoundException as e:
@@ -230,43 +231,43 @@ class TargetGroupManager(Manager):
     def list(self, load_balancer: str = None) -> Sequence["TargetGroup"]:
         kwargs = {}
         if load_balancer:
-            if not load_balancer.startswith('arn:'):
+            if not load_balancer.startswith("arn:"):
                 # This is a load balancer name
                 lb = LoadBalancer.objects.get(load_balancer)
                 load_balancer = lb.arn
-            kwargs['LoadBalancerArn'] = load_balancer
-        paginator = self.client.get_paginator('describe_target_groups')
+            kwargs["LoadBalancerArn"] = load_balancer
+        paginator = self.client.get_paginator("describe_target_groups")
         response_iterator = paginator.paginate(**kwargs)
         tgs = []
         try:
             for response in response_iterator:
-                tgs.extend(response['TargetGroups'])
+                tgs.extend(response["TargetGroups"])
         except self.client.exceptions.LoadBalancerNotFoundException as e:
             raise LoadBalancer.DoesNotExist(str(e))
         return [TargetGroup(tg) for tg in tgs]
 
-    def get_tags(self, arn: str) -> List[Dict[str, str]]:
+    def get_tags(self, arn: str) -> builtins.list[dict[str, str]]:
         try:
             response = self.client.describe_tags(ResourceArns=[arn])
         except self.client.exceptions.LoadBalancerNotFoundException as e:
             raise LoadBalancer.DoesNotExist(str(e))
-        return response['TagDescriptions']['Tags']
+        return response["TagDescriptions"]["Tags"]
 
 
 class TargetGroupTargetManager(Manager):
 
-    service = 'elbv2'
+    service = "elbv2"
 
-    def list(self, target_group_arn: str) -> Sequence['TargetGroupTarget']:
+    def list(self, target_group_arn: str) -> Sequence["TargetGroupTarget"]:
         try:
             response = self.client.describe_target_health(TargetGroupArn=target_group_arn)
         except self.client.exceptions.TargetGroupNotFoundException:
-            raise TargetGroup.DoesNotExist('TargetGroup("{}") does not exist in AWS'.format(target_group_arn))
+            raise TargetGroup.DoesNotExist(f'TargetGroup("{target_group_arn}") does not exist in AWS')
         targets = []
-        for data in response['TargetHealthDescriptions']:
-            target_data = data['Target']
-            target_data['TargetHealth'] = data['TargetHealth']
-            target_data['HealthCheckPort'] = data['HealthCheckPort']
+        for data in response["TargetHealthDescriptions"]:
+            target_data = data["Target"]
+            target_data["TargetHealth"] = data["TargetHealth"]
+            target_data["HealthCheckPort"] = data["HealthCheckPort"]
             targets.append(TargetGroupTarget(target_data))
         return targets
 
@@ -289,11 +290,11 @@ class LoadBalancer(TagsMixin, Model):
 
     @property
     def name(self) -> str:
-        return self.data['LoadBalancerName']
+        return self.data["LoadBalancerName"]
 
     @property
     def arn(self) -> str:
-        return self.data['LoadBalancerArn']
+        return self.data["LoadBalancerArn"]
 
     # ---------------------------------
     # LoadBalancer-specific properties
@@ -302,19 +303,19 @@ class LoadBalancer(TagsMixin, Model):
     @property
     def lb_type(self) -> str:
         alb_type = "Unknown"
-        if self.data['Type'] == 'application':
+        if self.data["Type"] == "application":
             alb_type = "ALB"
-        elif self.data['Type'] == 'network':
+        elif self.data["Type"] == "network":
             alb_type = "NLB"
         return alb_type
 
     @property
     def scheme(self) -> str:
-        return self.data['Scheme']
+        return self.data["Scheme"]
 
     @property
     def hostname(self) -> str:
-        return self.data['DNSName']
+        return self.data["DNSName"]
 
     # ------------------------------
     # Related objects
@@ -322,15 +323,15 @@ class LoadBalancer(TagsMixin, Model):
 
     @property
     def listeners(self) -> Sequence["LoadBalancerListener"]:
-        if 'listeners' not in self.cache:
-            self.cache['listeners'] = LoadBalancerListener.objects.list(load_balancer=self.arn)
-        return self.cache['listeners']
+        if "listeners" not in self.cache:
+            self.cache["listeners"] = LoadBalancerListener.objects.list(load_balancer=self.arn)
+        return self.cache["listeners"]
 
     @property
     def target_groups(self) -> Sequence["TargetGroup"]:
-        if 'target_groups' not in self.cache:
-            self.cache['target_groups'] = TargetGroup.objects.list(load_balancer=self.data['LoadBalancerArn'])
-        return self.cache['target_groups']
+        if "target_groups" not in self.cache:
+            self.cache["target_groups"] = TargetGroup.objects.list(load_balancer=self.data["LoadBalancerArn"])
+        return self.cache["target_groups"]
 
 
 class LoadBalancerListener(Model):
@@ -347,11 +348,11 @@ class LoadBalancerListener(Model):
 
     @property
     def name(self) -> str:
-        return f'{self.port} ({self.protocol})'
+        return f"{self.port} ({self.protocol})"
 
     @property
     def arn(self) -> str:
-        return self.data['ListenerArn']
+        return self.data["ListenerArn"]
 
     # ----------------------------------------
     # LoadBalancerListener-specific properties
@@ -359,19 +360,19 @@ class LoadBalancerListener(Model):
 
     @property
     def port(self) -> int:
-        return self.data['Port']
+        return self.data["Port"]
 
     @property
     def protocol(self) -> str:
-        return self.data['Protocol']
+        return self.data["Protocol"]
 
     @property
-    def ssl_certificates(self) -> List[str]:
-        return [c['CertificateArn'] for c in self.data.get('Certificates')]
+    def ssl_certificates(self) -> list[str]:
+        return [c["CertificateArn"] for c in self.data.get("Certificates")]
 
     @property
     def ssl_policy(self) -> str:
-        return self.data['SslPolicy']
+        return self.data["SslPolicy"]
 
     # ------------------------------
     # Related objects
@@ -379,24 +380,24 @@ class LoadBalancerListener(Model):
 
     @property
     def load_balancer(self) -> LoadBalancer:
-        if 'load_balancer' not in self.cache:
-            self.cache['load_balancer'] = LoadBalancer.objects.get(self.data['LoadBalancerArn'])
-        return self.cache['load_balancer']
+        if "load_balancer" not in self.cache:
+            self.cache["load_balancer"] = LoadBalancer.objects.get(self.data["LoadBalancerArn"])
+        return self.cache["load_balancer"]
 
     @property
     def rules(self) -> Sequence["LoadBalancerListenerRule"]:
-        if 'rules' not in self.cache:
-            self.cache['rules'] = LoadBalancerListenerRule.objects.list(listener_arn=self.arn)
-        return self.cache['rules']
+        if "rules" not in self.cache:
+            self.cache["rules"] = LoadBalancerListenerRule.objects.list(listener_arn=self.arn)
+        return self.cache["rules"]
 
 
 class LoadBalancerListenerRule(Model):
 
     objects = LoadBalancerListenerRuleManager()
 
-    def __init__(self, data: Dict[str, Any], listener_arn: str = None):
+    def __init__(self, data: dict[str, Any], listener_arn: str = None):
         super().__init__(data)
-        self.listener_arn: Optional[str] = listener_arn
+        self.listener_arn: str | None = listener_arn
 
     # ---------------------
     # Model overrides
@@ -412,7 +413,7 @@ class LoadBalancerListenerRule(Model):
 
     @property
     def arn(self) -> str:
-        return self.data['RuleArn']
+        return self.data["RuleArn"]
 
     # ------------------------------
     # Related objects
@@ -420,17 +421,17 @@ class LoadBalancerListenerRule(Model):
 
     @property
     def load_balancer(self) -> LoadBalancer:
-        if 'load_balancer' not in self.cache:
-            self.cache['load_balancer'] = LoadBalancer.objects.get(self.data['LoadBalancerArn'])
-        return self.cache['load_balancer']
+        if "load_balancer" not in self.cache:
+            self.cache["load_balancer"] = LoadBalancer.objects.get(self.data["LoadBalancerArn"])
+        return self.cache["load_balancer"]
 
     @property
-    def listener(self) -> Optional[LoadBalancerListener]:
-        if 'listener' not in self.cache and self.listener_arn:
-            self.cache['listener'] = LoadBalancerListener.objects.get(self.listener_arn)
+    def listener(self) -> LoadBalancerListener | None:
+        if "listener" not in self.cache and self.listener_arn:
+            self.cache["listener"] = LoadBalancerListener.objects.get(self.listener_arn)
         else:
-            self.cache['listener'] = None
-        return self.cache['listener']
+            self.cache["listener"] = None
+        return self.cache["listener"]
 
     @property
     def target_group(self) -> "TargetGroup":
@@ -444,13 +445,13 @@ class LoadBalancerListenerRule(Model):
             If we ever start doing green/blue deployments with two services attached to the same listener rule, we'll
             need to fix this.
         """
-        if 'target_group' not in self.cache:
+        if "target_group" not in self.cache:
             target_group = None
-            for action in self.data['Actions']:
-                if action['Type'] == 'forward':
-                    target_group = TargetGroup.objects.get(action['TargetGroupArn'])
-            self.cache['target_group'] = target_group
-        return self.cache['target_group']
+            for action in self.data["Actions"]:
+                if action["Type"] == "forward":
+                    target_group = TargetGroup.objects.get(action["TargetGroupArn"])
+            self.cache["target_group"] = target_group
+        return self.cache["target_group"]
 
 
 class TargetGroup(Model):
@@ -467,11 +468,11 @@ class TargetGroup(Model):
 
     @property
     def name(self) -> str:
-        return self.data['TargetGroupName']
+        return self.data["TargetGroupName"]
 
     @property
     def arn(self) -> str:
-        return self.data['TargetGroupArn']
+        return self.data["TargetGroupArn"]
 
     # ----------------------------------------
     # TargetGroup-specific properties
@@ -479,11 +480,11 @@ class TargetGroup(Model):
 
     @property
     def port(self) -> int:
-        return self.data['Port']
+        return self.data["Port"]
 
     @property
     def protocol(self) -> str:
-        return self.data['Protocol']
+        return self.data["Protocol"]
 
     # ------------------------------
     # Related objects
@@ -491,9 +492,9 @@ class TargetGroup(Model):
 
     @property
     def load_balancers(self) -> Sequence[LoadBalancer]:
-        if 'load_balancers' not in self.cache:
-            self.cache['load_balancers'] = LoadBalancer.objects.get_many(self.data['LoadBalancerArns'])
-        return self.cache['load_balancers']
+        if "load_balancers" not in self.cache:
+            self.cache["load_balancers"] = LoadBalancer.objects.get_many(self.data["LoadBalancerArns"])
+        return self.cache["load_balancers"]
 
     @property
     def rules(self) -> Sequence[LoadBalancerListenerRule]:
@@ -504,13 +505,13 @@ class TargetGroup(Model):
             what listener rules it is attached to -- you have to start at the
             load balancer, list all the listener rules that
         """
-        if 'listener_rules' not in self.cache:
-            self.cache['listener_rules'] = LoadBalancerListenerRule.objects.list(target_group_arn=self.arn)
-        return self.cache['listener_rules']
+        if "listener_rules" not in self.cache:
+            self.cache["listener_rules"] = LoadBalancerListenerRule.objects.list(target_group_arn=self.arn)
+        return self.cache["listener_rules"]
 
     @property
     def listeners(self) -> Sequence[LoadBalancerListener]:
-        if 'listeners' not in self.cache:
+        if "listeners" not in self.cache:
             listeners = {}
             # First extract the listeners from any rules we have
             for rule in self.rules:
@@ -519,12 +520,12 @@ class TargetGroup(Model):
             # if we're the default action on any of them
             for lb in self.load_balancers:
                 for listener in lb.listeners:
-                    if 'DefaultActions' in listener.data:
-                        for action in listener.data['DefaultActions']:
-                            if action['Type'] == 'forward' and 'TargetGroupArn' in action:
+                    if "DefaultActions" in listener.data:
+                        for action in listener.data["DefaultActions"]:
+                            if action["Type"] == "forward" and "TargetGroupArn" in action:
                                 listeners[listener.arn] = listener
-            self.cache['listeners'] = list(listeners.values())
-        return self.cache['listeners']
+            self.cache["listeners"] = list(listeners.values())
+        return self.cache["listeners"]
 
     @property
     def targets(self) -> Sequence["TargetGroupTarget"]:
@@ -541,7 +542,7 @@ class TargetGroupTarget(Model):
 
     @property
     def pk(self) -> str:
-        return self.data['Id']
+        return self.data["Id"]
 
     @property
     def name(self) -> str:
@@ -557,11 +558,11 @@ class TargetGroupTarget(Model):
 
     @property
     def port(self) -> int:
-        return self.data['Port']
+        return self.data["Port"]
 
     @property
     def health(self) -> str:
-        return self.data['TargetHealth']
+        return self.data["TargetHealth"]
 
     # ------------------------------
     # Related objects
@@ -569,18 +570,18 @@ class TargetGroupTarget(Model):
 
     @property
     def target(self) -> Instance:
-        if 'target' not in self.cache:
-            if self.data['Id'].startswith('i-'):
+        if "target" not in self.cache:
+            if self.data["Id"].startswith("i-"):
                 # this is an instance
-                self.cache['target'] = Instance.objects.get(self.data['Id'])
+                self.cache["target"] = Instance.objects.get(self.data["Id"])
             else:
                 raise self.OperationFailed(
-                    'TargetGroupTarget("{}"): currently can\'t defereference targets of this type'.format(self.pk)
+                    f'TargetGroupTarget("{self.pk}"): currently can\'t defereference targets of this type'
                 )
-        return self.cache['target']
+        return self.cache["target"]
 
     @property
     def target_group(self) -> TargetGroup:
-        if 'target_group' not in self.cache:
-            self.cache['target_group'] = TargetGroup.objects.get(self.data['TargetGroupArn'])
-        return self.cache['target_group']
+        if "target_group" not in self.cache:
+            self.cache["target_group"] = TargetGroup.objects.get(self.data["TargetGroupArn"])
+        return self.cache["target_group"]
