@@ -1,6 +1,8 @@
-import sys
+import builtins
 import json
-from typing import Dict, Any, Sequence, List, Union, Type, Tuple, Optional
+import sys
+from collections.abc import Sequence
+from typing import Any
 
 from jsondiff import diff
 
@@ -11,7 +13,7 @@ from .abstract import Manager, Model
 if sys.version_info >= (3, 8):
     from typing import Protocol
 else:
-    from typing_extensions import Protocol
+    from typing import Protocol
 
 
 # ----------------------------------------
@@ -25,11 +27,10 @@ class SupportsSecrets(SupportsCache, Protocol):
         ...
 
     @property
-    def secrets(self) -> Dict[str, "Secret"]:
+    def secrets(self) -> dict[str, "Secret"]:
         ...
 
 
-
 # ----------------------------------------
 # Mixins
 # ----------------------------------------
@@ -41,12 +42,12 @@ class SecretsMixin:
         raise NotImplementedError
 
     @property
-    def secrets(self: SupportsSecrets) -> Dict[str, "Secret"]:
-        return self.cache['secrets']
+    def secrets(self: SupportsSecrets) -> dict[str, "Secret"]:
+        return self.cache["secrets"]
 
     @secrets.setter
-    def secrets(self: SupportsSecrets, value: Dict[str, "Secret"]) -> None:
-        self.cache['secrets'] = value
+    def secrets(self: SupportsSecrets, value: dict[str, "Secret"]) -> None:
+        self.cache["secrets"] = value
 
     def write_secrets(self: SupportsSecrets) -> None:
         # Add and update secrets we do need
@@ -64,10 +65,10 @@ class SecretsMixin:
                 Secret.objects.delete_many_by_name(for_deletion)
 
     def reload_secrets(self: SupportsSecrets) -> None:
-        if 'secrets' in self.cache:
-            del self.cache['secrets']
+        if "secrets" in self.cache:
+            del self.cache["secrets"]
 
-    def diff_secrets(self: SupportsSecrets, other: Sequence["Secret"], ignore_external: bool = False) -> Dict[str, Any]:
+    def diff_secrets(self: SupportsSecrets, other: Sequence["Secret"], ignore_external: bool = False) -> dict[str, Any]:
         """
         Diff our list of Secrets against `other`.
 
@@ -88,7 +89,7 @@ class SecretsMixin:
         if other:
             their_secrets = sorted(other, key=lambda x: x.name)
             them = {s.name: s.render_for_diff() for s in their_secrets}
-        return json.loads(diff(them, us, syntax='explicit', dump=True))
+        return json.loads(diff(them, us, syntax="explicit", dump=True))
 
 
 # ----------------------------------------
@@ -96,31 +97,37 @@ class SecretsMixin:
 # ----------------------------------------
 
 class SecretManager(Manager):
+    """
+    Manage our SSM Parameter Store parameters.   This differs from
+    :py:class:`deployfish.core.models.secrets_manager.SecretManager`  in that
+    that manager manages Secrets Manager secrets, not SSM Parameter Store
+    parameters.
+    """
 
-    service = 'ssm'
+    service = "ssm"
 
-    def __init__(self, model: Union[Type["Secret"], Type["ExternalSecret"]], readonly: bool = False) -> None:
+    def __init__(self, model: type["Secret"] | type["ExternalSecret"], readonly: bool = False) -> None:
         self.model = model
         self.readonly = readonly
         super().__init__()
 
-    def _describe_parameters(self, key: str, option: str = 'prefix') -> List[Dict[str, Any]]:
-        if option == 'prefix':
-            option = 'BeginsWith'
+    def _describe_parameters(self, key: str, option: str = "prefix") -> list[dict[str, Any]]:
+        if option == "prefix":
+            option = "BeginsWith"
         else:
-            option = 'Equals'
-        paginator = self.client.get_paginator('describe_parameters')
+            option = "Equals"
+        paginator = self.client.get_paginator("describe_parameters")
         response_iterator = paginator.paginate(
             ParameterFilters=[
-                {'Key': 'Name', 'Option': option, 'Values': [key]}
+                {"Key": "Name", "Option": option, "Values": [key]}
             ]
         )
         parameters = []
         for page in response_iterator:
-            parameters.extend(page['Parameters'])
+            parameters.extend(page["Parameters"])
         return parameters
 
-    def _get_parameter_values(self, names: List[str]) -> Tuple[Dict[str, Any], List[str]]:
+    def _get_parameter_values(self, names: list[str], decrypt: bool = True) -> tuple[dict[str, Any], list[str]]:
         # get_parameters only accepts 10 or fewer names in the Names kwarg, so we have to
         # split names into sub lists of 10 of fewer names and iterate
         names_chunks = [names[i * 10:(i + 1) * 10] for i in range((len(names) + 9) // 10)]
@@ -128,29 +135,29 @@ class SecretManager(Manager):
         non_existant = []
         for chunk in names_chunks:
             try:
-                response = self.client.get_parameters(Names=chunk, WithDecryption=True)
+                response = self.client.get_parameters(Names=chunk, WithDecryption=decrypt)
             except self.client.exceptions.InvalidKeyId as e:
                 raise self.model.DecryptionFailed(str(e))
-            if 'InvalidParameters' in response and response['InvalidParameters']:
-                non_existant.extend(response['InvalidParameters'])
-            parameters.extend(response['Parameters'])
-        return {p['Name']: p for p in parameters}, non_existant
+            if response.get("InvalidParameters"):
+                non_existant.extend(response["InvalidParameters"])
+            parameters.extend(response["Parameters"])
+        return {p["Name"]: p for p in parameters}, non_existant
 
-    def convert(self, parameter_data: Dict[str, Any]) -> "Secret":
-        name = parameter_data['Name'].split('.')[-1]
+    def convert(self, parameter_data: dict[str, Any]) -> "Secret":
+        name = parameter_data["Name"].split(".")[-1]
         return self.model(parameter_data, name=name)
 
     def get(self, pk: str, **_) -> "Secret":
         values, non_existant_parameters = self._get_parameter_values([pk])
-        params = self._describe_parameters(pk, option='equals')
+        params = self._describe_parameters(pk, option="equals")
         if non_existant_parameters:
-            raise Secret.DoesNotExist('No secret named {} exists in AWS'.format(pk))
+            raise Secret.DoesNotExist(f"No secret named {pk} exists in AWS")
         data = params[0]
-        data['ARN'] = values[pk]['ARN']
-        data['Value'] = values[pk]['Value']
+        data["ARN"] = values[pk]["ARN"]
+        data["Value"] = values[pk]["Value"]
         return self.convert(data)
 
-    def get_many(self, pks: List[str], **_) -> Sequence["Secret"]:
+    def get_many(self, pks: list[str], **_) -> Sequence["Secret"]:
         """
 
         .. note::
@@ -165,63 +172,63 @@ class SecretManager(Manager):
         prefixes = set()
         # FIXME: we're getting all parameters for a service even if we wanted just a few, and that takes a long time.
         # Find the breakeven point below which it's faster to get parameters individually and above which is better to
-        # get all the paramters.
+        # get all the parameters.
         for pk in pks:
-            prefixes.add(pk.rsplit('.', 1)[0])
+            prefixes.add(pk.rsplit(".", 1)[0] + ".")
         descriptions = {}
         for prefix in prefixes:
             params = self._describe_parameters(prefix)
             for p in params:
-                descriptions[p['Name']] = p
+                descriptions[p["Name"]] = p
         secrets = []
         for name, data in list(descriptions.items()):
             if name in values:
-                data['ARN'] = values[name]['ARN']
-                data['Value'] = values[name]['Value']
+                data["ARN"] = values[name]["ARN"]
+                data["Value"] = values[name]["Value"]
             secrets.append(self.convert(data))
         # Fake the non-existant parameters
         for param in non_existant_parameters:
             data = {
-                'Name': param,
-                'Type': 'String',
-                'Tier': 'Standard'
+                "Name": param,
+                "Type": "String",
+                "Tier": "Standard"
             }
             secrets.append(self.convert(data))
         return secrets
 
-    def list_names(self, prefix: str) -> List[str]:
-        if prefix.endswith('*'):
+    def list_names(self, prefix: str) -> list[str]:
+        if prefix.endswith("*"):
             prefix = prefix[:-1]
-            if not prefix.endswith('.'):
+            if not prefix.endswith("."):
                 prefix = prefix + "."
         parameters = self._describe_parameters(prefix)
-        return [p['Name'] for p in parameters]
+        return [p["Name"] for p in parameters]
 
-    def list(self, prefix: str) -> Sequence["Secret"]:
-        if prefix.endswith('*'):
+    def list(self, prefix: str, decrypt: bool = True) -> Sequence["Secret"]:
+        if prefix.endswith("*"):
             prefix = prefix[:-1]
-            if not prefix.endswith('.'):
+            if not prefix.endswith("."):
                 prefix = prefix + "."
         parameters = self._describe_parameters(prefix)
         # We have to do two loops here, because describe_parameters gives us the
         # KeyId for our KMS key, but does not give us Value or ARN, while
         # get_parameters gives us Value and ARN but no KeyId
-        names = [parameter['Name'] for parameter in parameters]
-        values, _ = self._get_parameter_values(names)
+        names = [parameter["Name"] for parameter in parameters]
+        values, _ = self._get_parameter_values(names, decrypt=decrypt)
         secrets = []
         for parameter in parameters:
-            parameter['ARN'] = values[parameter['Name']]['ARN']
-            parameter['Value'] = values[parameter['Name']]['Value']
+            parameter["ARN"] = values[parameter["Name"]]["ARN"]
+            parameter["Value"] = values[parameter["Name"]]["Value"]
             secrets.append(self.convert(parameter))
         return secrets
 
     def save(self, obj: Model, **_) -> str:
         if not self.readonly:
             response = self.client.put_parameter(**obj.render_for_create())
-            return response['Version']
-        raise self.model.ReadOnly('This Secret is read only.')
+            return response["Version"]
+        raise self.model.ReadOnly("This Secret is read only.")
 
-    def delete_many_by_name(self, pks: List[str]) -> None:
+    def delete_many_by_name(self, pks: builtins.list[str]) -> None:
         if len(pks) <= 10:
             self.client.delete_parameters(Names=pks)
         else:
@@ -233,7 +240,7 @@ class SecretManager(Manager):
 
     def delete(self, obj: Model, **_) -> None:
         if self.readonly:
-            raise self.model.ReadOnly('This Secret is read only.')
+            raise self.model.ReadOnly("This Secret is read only.")
         try:
             self.client.delete_parameter(Name=obj.pk)
         except self.client.exceptions.ParameterNotFound:
@@ -254,7 +261,7 @@ class Secret(Model):
     class DecryptionFailed(Exception):
         pass
 
-    def __init__(self, data: Dict[str, Any], name: str = ''):
+    def __init__(self, data: dict[str, Any], name: str = ""):
         super().__init__(data)
         self.secret_name = name
 
@@ -264,7 +271,7 @@ class Secret(Model):
 
     @property
     def pk(self) -> str:
-        return self.data['Name']
+        return self.data["Name"]
 
     @property
     def name(self) -> str:
@@ -272,27 +279,27 @@ class Secret(Model):
 
     @property
     def arn(self) -> str:
-        return self.data.get('ARN', None)
+        return self.data.get("ARN", None)
 
-    def render_for_create(self) -> Dict[str, Any]:
+    def render_for_create(self) -> dict[str, Any]:
         data = self.render()
-        if 'ARN' in data:
-            del data['ARN']
-            del data['LastModifiedDate']
-            del data['LastModifiedUser']
-            del data['Version']
-        data['Overwrite'] = True
+        if "ARN" in data:
+            del data["ARN"]
+            del data["LastModifiedDate"]
+            del data["LastModifiedUser"]
+            del data["Version"]
+        data["Overwrite"] = True
         return data
 
     def render_for_diff(self):
         data = self.render()
-        data['EnvVar'] = self.secret_name
-        if 'ARN' in data:
-            del data['ARN']
-            del data['LastModifiedDate']
-            del data['LastModifiedUser']
-            del data['Version']
-            del data['Policies']
+        data["EnvVar"] = self.secret_name
+        if "ARN" in data:
+            del data["ARN"]
+            del data["LastModifiedDate"]
+            del data["LastModifiedUser"]
+            del data["Version"]
+            del data["Policies"]
         return data
 
     # ----------------------------
@@ -301,39 +308,39 @@ class Secret(Model):
 
     @property
     def prefix(self) -> str:
-        return self.data['Name'].rsplit('.', 1)[0]
+        return self.data["Name"].rsplit(".", 1)[0]
 
     @prefix.setter
     def prefix(self, value: str) -> None:
-        self.data['Name'] = f'{value}.{self.secret_name}'
+        self.data["Name"] = f"{value}.{self.secret_name}"
 
     @property
     def is_secure(self) -> bool:
         return self.kms_key_id is not None
 
     @property
-    def modified_username(self) -> Optional[str]:
-        user = self.data.get('LastModifiedUser', None)
+    def modified_username(self) -> str | None:
+        user = self.data.get("LastModifiedUser", None)
         if user:
-            return user.rsplit('/', 1)[1]
+            return user.rsplit("/", 1)[1]
         return None
 
     @property
     def kms_key_id(self) -> str:
-        return self.data.get('KeyId', None)
+        return self.data.get("KeyId", None)
 
     @kms_key_id.setter
     def kms_key_id(self, value: str) -> None:
-        self.data['Type'] = 'SecureString'
-        self.data['KeyId'] = value
+        self.data["Type"] = "SecureString"
+        self.data["KeyId"] = value
 
     @property
     def value(self) -> str:
-        return self.data['Value']
+        return self.data["Value"]
 
     @value.setter
     def value(self, value: str) -> None:
-        self.data['Value'] = value
+        self.data["Value"] = value
 
     # ------------------------
     # Secret-specific actions
@@ -341,17 +348,17 @@ class Secret(Model):
 
     def copy(self) -> "Secret":
         data = self.render()
-        if 'ARN' in data:
-            del data['ARN']
-            del data['LastModifiedDate']
-            del data['LastModifiedUser']
-            del data['Version']
+        if "ARN" in data:
+            del data["ARN"]
+            del data["LastModifiedDate"]
+            del data["LastModifiedUser"]
+            del data["Version"]
         obj = self.__class__(data, self.secret_name)
         return obj
 
     def __str__(self) -> str:
-        line = f'{self.secret_name}={self.value}'
-        if self.data['Type'] == 'SecureString':
+        line = f"{self.secret_name}={self.value}"
+        if self.data["Type"] == "SecureString":
             line = f"{line} [SECURE:{self.kms_key_id}]"
         return line
 
