@@ -1,2 +1,2 @@
 from .abstract import AbstractRenderer  # noqa:F401
-from .table import *  # noqa:F403,F401
+from .table import *  # noqa: F403
